# pychemcurv web application

This directory contained the source code of a web application that 
aims to provide an easy way to test pychemcurv online.

The source code of the application is now available
in a separate repository at [pychemcurv-app](https://github.com/gVallverdu/pychemcurv-app).

The web application is available at
[pychemcurv.onrender.com/](https://pychemcurv.onrender.com).
It allows to upload simple xyz files and compute the local geometrical
properties and the hybridization properties. 

Demo video:

[![youtube demo video](https://img.youtube.com/vi/q7UO5Gou-lw/0.jpg)](https://www.youtube.com/watch?v=q7UO5Gou-lw)